==> vcf-date-range-picker-4.6.2.tgz: package/README.md <==
[![npm version](https://badgen.net/npm/v/@vaadin-component-factory/vcf-date-range-picker)](https://www.npmjs.com/package/@vaadin-component-factory/vcf-date-range-picker)

[![Published on Vaadin  Directory](https://img.shields.io/badge/Vaadin%20Directory-published-00b4f0.svg)](https://vaadin.com/directory/component/vaadin-component-factoryvcf-date-range-picker)
[![Stars on vaadin.com/directory](https://img.shields.io/vaadin-directory/star/vaadinvcf-date-range-picker.svg)](https://vaadin.com/directory/component/vaadin-component-factoryvcf-date-range-picker)

# &lt;vcf-date-range-picker&gt;

[&lt;vcf-date-range-picker&gt;](https://vaadin.com/components/vcf-date-range-picker) is a Web Component providing a date range selection field which includes a scrollable month calendar view.

```html
<vcf-date-range-picker label="From" end-label="To" value="1990-01-28" end-value="1990-01-30">
</vcf-date-range-picker>
```

[<img src="./screenshot.png" width="439" alt="Screenshot of vcf-date-range-picker">](https://vaadin.com/components/vcf-date-range-picker)

## Running demo

1. Fork the `vcf-date-range-picker` repository and clone it locally.

1. Make sure you have [npm](https://www.npmjs.com/) installed.

1. When in the `vcf-date-range-picker` directory, run `npm install` to install dependencies.

1. Run `npm start` to open the demo.

## Contributing

To contribute to the component, please read [the guideline](https://github.com/vaadin/vaadin-core/blob/master/CONTRIBUTING.md) first.

## License

Apache License 2.0

==> vcf-date-range-picker-4.8.0.tgz: package/README.md <==
[![npm version](https://badgen.net/npm/v/@vaadin-component-factory/vcf-date-range-picker)](https://www.npmjs.com/package/@vaadin-component-factory/vcf-date-range-picker)

[![Published on Vaadin  Directory](https://img.shields.io/badge/Vaadin%20Directory-published-00b4f0.svg)](https://vaadin.com/directory/component/vaadin-component-factoryvcf-date-range-picker)
[![Stars on vaadin.com/directory](https://img.shields.io/vaadin-directory/star/vaadinvcf-date-range-picker.svg)](https://vaadin.com/directory/component/vaadin-component-factoryvcf-date-range-picker)

# &lt;vcf-date-range-picker&gt;

[&lt;vcf-date-range-picker&gt;](https://vaadin.com/components/vcf-date-range-picker) is a Web Component providing a date range selection field which includes a scrollable month calendar view.

```html
<vcf-date-range-picker label="Enter date range" value="1990-01-28" end-value="1990-01-30">
</vcf-date-range-picker>
```

[<img src="./screenshot.png" width="439" alt="Screenshot of vcf-date-range-picker">](https://vaadin.com/components/vcf-date-range-picker)

## Running demo

1. Fork the `vcf-date-range-picker` repository and clone it locally.

1. Make sure you have [npm](https://www.npmjs.com/) installed.

1. When in the `vcf-date-range-picker` directory, run `npm install` to install dependencies.

1. Run `npm start` to open the demo.

## Contributing

To contribute to the component, please read [the guideline](https://github.com/vaadin/vaadin-core/blob/master/CONTRIBUTING.md) first.

## License

Apache License 2.0
